@@ -60,7 +60,7 @@ class BlockPyEnvironment(Environment):
                  user=None, assignment=None, course=None, execution=None,
                  instructor_file='on_run.py', skip_tifa=False, skip_run=False,
                  inputs=None, set_success=True,
-                 report=MAIN_REPORT, trace=True):
+                 report=MAIN_REPORT, trace=True, threaded=False):
         super().__init__(files=files, main_file=main_file, main_code=main_code,
                          user=user, assignment=assignment, course=course,
                          execution=execution, instructor_file=instructor_file,
@@ -73,10 +73,12 @@ class BlockPyEnvironment(Environment):
             set_input(inputs)
         if skip_run:
             student = get_sandbox(report=report)
+            student.threaded = threaded
         else:
             if trace:
                 start_trace()
-            student = run(report=report)
+            student = run(report=report, threaded=threaded)
+            student.threaded = threaded
         self.fields = {
             'student': student,
             'resolve': resolve,
