@@ -1,8 +1,7 @@
-try:
-    TimeoutError
-except NameError:
-    class TimeoutError(Exception):
-        pass
+"""
+Exceptions related to Sandbox execution; note that these are not meant for
+students, they indicate system errors.
+"""
 
 
 class SandboxException(Exception):
