@@ -13,7 +13,7 @@ modified such that the current submission is replaced by the current file.
 
 from pedal.source.constants import TOOL_NAME
 from pedal.source.sections import (separate_into_sections, check_section_exists,
-                                   finish_section, next_section)
+                                   stop_sections, next_section)
 from pedal.source.source import (verify, verify_section, set_source, set_source_file, get_program)
 
 
